[![codecov](https://codecov.io/gh/django-advance-utils/geometry-utils/branch/main/graph/badge.svg?token=BF9hnkXKp3)](https://codecov.io/gh/django-advance-utils/geometry-utils)



=======
# geometry-utils
## Introduction
A python module for working on 2D and 3D geometries.

